﻿# 設定目標子目錄
$targetFolder = ".\pac"  # 若需完整路徑可替換為 "D:\...\pac"

# 讀取 CSV 文件（需與腳本同目錄）
$chsList = Import-Csv -Path "chs.csv" -Header "Name" -Encoding UTF8 | Select-Object -Skip 1
$jpnList = Import-Csv -Path "jpn.csv" -Header "Name" -Encoding UTF8 | Select-Object -Skip 1

# 校驗一致性和目錄存在性
if ($chsList.Count -ne $jpnList.Count) {
    Write-Host "錯誤：chs.csv 和 jpn.csv 行數不一致" -ForegroundColor Red
    exit
}
if (-not (Test-Path -Path $targetFolder)) {
    Write-Host "錯誤：目標目錄 $targetFolder 不存在" -ForegroundColor Red
    exit
}

# 遍歷並重命名
for ($i = 0; $i -lt $jpnList.Count; $i++) {
    $oldName = Join-Path -Path $targetFolder -ChildPath $jpnList[$i].Name
    $newName = $chsList[$i].Name

    if (Test-Path -Path $oldName) {
        try {
            Rename-Item -Path $oldName -NewName $newName -Force
            Write-Host "成功：[$($jpnList[$i].Name)] -> [$($chsList[$i].Name)]" -ForegroundColor Green
        } catch {
            Write-Host "失敗：重命名 $oldName 時出錯 - $_" -ForegroundColor Red
        }
    } else {
        Write-Host "警告：文件 $oldName 不存在" -ForegroundColor Yellow
    }
}